/*
 * mct8316z_spi.c
 */

#include <mct8316z_spi.h>
#include <callbacks.h>
#include <msp430.h>
#include <stdbool.h>

#define SPI_DELAY 10

volatile unsigned char dataMSB, dataLSB;
extern volatile unsigned char TXData, RXData;



void SPI_Write(unsigned short address, unsigned short data)
{
   volatile unsigned char addr, dat;

   dat = data;
   addr = address;

   addr = ((addr << 1) & 0x7E);          //line up A5-A0 in MSB
   dat = (dat & 0xFF);                 //line up D7-D0 in LSB

   bool parity = parityCheck_write(addr,dat);

   dataLSB = data;                       //LSB = D7-D0
   dataMSB = (addr | parity);            //MSB = W0=0, A5-A0, P

   TXData = dataMSB;
   P4OUT &= ~BIT4;                       //nSCS low to start SPI write
   UCB1IE |= UCTXIE;
   __bis_SR_register(LPM0_bits | GIE);   // enable global interrupts, enter LPM0
   __no_operation();                     // For debug,Remain in LPM0
   TXData = dataLSB;
   UCB1IE |= UCTXIE;
   __bis_SR_register(LPM0_bits | GIE);   // enable global interrupts, enter LPM0
   __no_operation();                     // For debug,Remain in LPM0

   P4OUT |= BIT4;                        //nSCS high to end SPI write
   SPIDelay();
}

unsigned short SPI_Read(unsigned short address)
{
    address = ((address << 1) & 0x7E);           //line up A5-A0 in MSB

    bool parity = parityCheck_read(address);

    dataLSB = 0xFF;                      //LSB = dummy data (D7-D0)
    dataMSB = (0x80 | address | parity);    //MSB = W0=1, A5-A0, P

    TXData = dataMSB;
    P4OUT &= ~BIT4;                        //nSCS low to start SPI read
    UCB1IE |= UCTXIE;
    __bis_SR_register(LPM0_bits | GIE);   // enable global interrupts, enter LPM0
    __no_operation();                     // For debug,Remain in LPM0
    dataMSB = RXData;

    TXData = dataLSB;
    UCB1IE |= UCTXIE;
    __bis_SR_register(LPM0_bits | GIE);   // enable global interrupts, enter LPM0
    __no_operation();                     // For debug,Remain in LPM0
    dataLSB = RXData & 0xFF;

    P4OUT |= BIT4;                        //nSCS high to end SPI read
    SPIDelay();

    return (RXData);
}

void SPIDelay(void)
{
    volatile unsigned int Delay_Count;

    for(Delay_Count = SPI_DELAY; Delay_Count > 0; Delay_Count--)
    {
        ;                                                                                // Wait for slave to initialize
    }
}

static bool parityCheck_write(uint8_t addr, uint8_t data)
{
    volatile unsigned char parity = 0, parity_check = 0, i = 0;
    volatile unsigned int parity_word = (addr << 8) | data;
    for (i=0;i<14;i++)
    {
        parity_check = (parity_word >> i) & 1;
        if (parity_check == 1)
        {
            parity ^= 1;
        }
    }
    return parity;
}

static bool parityCheck_read(uint8_t addr)
{
    volatile unsigned char parity = 0, parity_check = 0, i = 0;
    volatile unsigned int parity_word = (addr << 8);
    for (i=0;i<14;i++)
    {
        parity_check = (parity_word >> i) & 1;
        if (parity_check == 1)
        {
            parity ^= 1;
        }
    }
    return parity;
}

void SPI_Write_All(void)
{
    unsigned short address, data;

    //CTRL1
    address = 3;
    data = (REG_LOCK2 << 2) |
           (REG_LOCK1 << 1) |
           (REG_LOCK0 << 0);
    SPI_Write(address, data);

    //CTRL2
    address = 4;
    data = (SLEW1 << 4) |
           (SLEW0 << 3) |
           (PWM_MODE1 << 2) |
           (PWM_MODE0 << 1) |
           (CLR_FLT << 0);
    SPI_Write(address, data);

    //CTRL3
    address = 5;
    data = (OVP_SEL << 3) |
           (OVP_EN << 2) |
           (SPI_FLT_REP << 1) |
           (OTW_REP << 0);
    SPI_Write(address, data);

    //CTRL4
    address = 6;
    data = (OCP_CBC << 6) |
           (OCP_DEG1 << 5) |
           (OCP_DEG0 << 4) |
           (OCP_RETRY << 3) |
           (OCP_LVL << 2) |
           (OCP_MODE1 << 1) |
           (OCP_MODE0 << 0);
    SPI_Write(address, data);

    //CTRL5
    address = 7;
    data = (BEMF_TH << 7) |
           (ILIM_RECIR << 6) |
           (AD_COMP_TH_LS << 5) |
           (AD_COMP_TH_HS << 4) |
           (EN_AAR << 3) |
           (EN_ASR << 2) |
           (CSA_GAIN1 << 1) |
           (CSA_GAIN0 << 0);
    SPI_Write(address, data);

    //CTRL6
    address = 8;
    data = (BUCK_SR << 5) |
           (BUCK_PS_DIS << 4) |
           (BUCK_CL << 3) |
           (BUCK_SEL1 << 2) |
           (BUCK_SEL0 << 1) |
           (BUCK_DIS << 0);
    SPI_Write(address, data);

    //CTRL7
    address = 9;
    data = (HALL_HYS << 4) |
           (BRAKE_MODE << 3) |
           (COAST << 2) |
           (BRAKE << 1) |
           (DIR << 0);
    SPI_Write(address, data);

    //CTRL8
    address = 10;
    data = (FG_MODE1 << 7) |
           (FG_MODE0 << 6) |
           (DIS_MTR_LOCK << 5) |
           (MOTOR_LOCK_RETRY << 4) |
           (MOTOR_LOCK_TDET1 << 3) |
           (MOTOR_LOCK_TDET0 << 2) |
           (MOTOR_LOCK_MODE1 << 1) |
           (MOTOR_LOCK_MODE0 << 0);
    SPI_Write(address, data);

    //CTRL9
    address = 11;
    data = (ADVANCE2 << 2) |
           (ADVANCE1 << 1) |
           (ADVANCE0 << 0);
    SPI_Write(address, data);
}

void SPI_Read_All(void)
{
    unsigned short address;

    for(address = 0; address < 12; address++)
    {
        unsigned short receivedData = SPI_Read(address);
        UpdateSpiReg(address, receivedData);
    }
}

void SPI_SetupDrv(void)
{
    SPI_Write(0x03,0x03); //unlock SPI
    SPIDelay();
    SPI_Write(0x04,0x02); //SR = 200V/us, Asynch rectification w/ digital Hall
    SPIDelay();
}

void UpdateSpiReg(unsigned short address, unsigned short data)
{
    bool bit = 0;
    switch (address)
    {
    case 0:
        bit = (data >> 7) & 1;
        GUIComm_sendUInt8("MTR_LOCK",8,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendUInt8("BK_FLT",6,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendUInt8("SPI_FLT",7,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendUInt8("OCP",3,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendUInt8("NPOR",4,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendUInt8("OVP",3,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendUInt8("OT",2,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendUInt8("FAULT",5,bit);
        break;
    case 1:
        bit = (data >> 7) & 1;
        GUIComm_sendUInt8("OTW",3,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendUInt8("OTS",3,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendUInt8("OCP_HC",6,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendUInt8("OCP_LC",6,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendUInt8("OCP_HB",6,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendUInt8("OCP_LB",6,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendUInt8("OCP_HA",6,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendUInt8("OCP_LA",6,bit);
        break;
    case 2:
        bit = (data >> 7) & 1;
        GUIComm_sendUInt8("STAT2_RSV",9,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendUInt8("OTP_ERR",7,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendUInt8("BUCK_OCP",8,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendUInt8("BUCK_UV",7,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendUInt8("VCP_UV",6,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendUInt8("SPI_PARITY",10,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendUInt8("SPI_SCLK_FLT",12,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendUInt8("SPI_ADDR_FLT",12,bit);
        break;
    case 3:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL1_RSV5",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL1_RSV4",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("CTRL1_RSV3",10,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("CTRL1_RSV2",10,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("CTRL1_RSV1",10,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("REG_LOCK2",9,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("REG_LOCK1",9,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("REG_LOCK0",9,bit);
        break;
    case 4:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL2_RSV3",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL2_RSV2",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("CTRL2_RSV1",10,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("SLEW1",5,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("SLEW0",5,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("PWM_MODE1",9,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("PWM_MODE0",9,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("CLR_FLT",7,bit);
        break;
    case 5:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL3_RSV4",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL3_RSV3",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("CTRL3_RSV2",10,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("CTRL3_RSV1",10,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("OVP_SEL",7,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("OVP_EN",6,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("SPI_FLT_REP",11,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("OTW_REP",7,bit);
        break;
    case 6:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL4_RSV",9,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("OCP_CBC",7,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("OCP_DEG1",8,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("OCP_DEG0",8,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("OCP_RETRY",9,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("OCP_LVL",7,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("OCP_MODE1",9,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("OCP_MODE0",9,bit);
        break;
    case 7:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("BEMF_TH",7,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("ILIM_RECIR",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("AD_COMP_TH_LS",13,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("AD_COMP_TH_HS",13,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("EN_AAR",6,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("EN_ASR",6,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("CSA_GAIN1",9,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("CSA_GAIN0",9,bit);
        break;
    case 8:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL6_RSV2",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL6_RSV1",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("BUCK_SR",7,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("BUCK_PS_DIS",11,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("BUCK_CL",7,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("BUCK_SEL1",9,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("BUCK_SEL0",9,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("BUCK_DIS",8,bit);
        break;
    case 9:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL7_RSV3",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL7_RSV2",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("CTRL7_RSV1",10,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("HALL_HYS",8,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("BRAKE_MODE",10,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("COAST",5,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("BRAKE",5,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("DIR",3,bit);
        break;
    case 10:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("FG_MODE1",8,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("FG_MODE0",8,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("DIS_MTR_LOCK",12,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("MOTOR_LOCK_RETRY",16,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("MOTOR_LOCK_TDET1",16,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("MOTOR_LOCK_TDET0",16,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("MOTOR_LOCK_MODE1",16,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("MOTOR_LOCK_MODE0",16,bit);
        break;
    case 11:
        bit = (data >> 7) & 1;
        GUIComm_sendBool("CTRL9_RSV5",10,bit);
        bit = (data >> 6) & 1;
        GUIComm_sendBool("CTRL9_RSV4",10,bit);
        bit = (data >> 5) & 1;
        GUIComm_sendBool("CTRL9_RSV3",10,bit);
        bit = (data >> 4) & 1;
        GUIComm_sendBool("CTRL9_RSV2",10,bit);
        bit = (data >> 3) & 1;
        GUIComm_sendBool("CTRL9_RSV1",10,bit);
        bit = (data >> 2) & 1;
        GUIComm_sendBool("ADVANCE2",8,bit);
        bit = (data >> 1) & 1;
        GUIComm_sendBool("ADVANCE1",8,bit);
        bit = (data >> 0) & 1;
        GUIComm_sendBool("ADVANCE0",8,bit);
        break;
    default:
        break;
    }
}
